import { ElementType, useState } from "react";

export const WithHocSearch = (Component: ElementType) => {
  return function WithHocSearchComponent({ ...props }: {
    [key: string]: any;
  }) {
    let [search, setSearch] = useState<string>('');

    return (
      <Component
        handleSearch={({ target }: any) => setSearch(target.value)}
        handleSearchTrigger={(e: any) => {
          e.preventDefault();
          setSearch(e.currentTarget.elements[0].value);
        }}
        handleSearchReset={({ keyCode }: any) => {
          if (keyCode === 8) setSearch('');
        }}
        filterData={(data: any[]) => {
          return data.filter(datum => {
            let searchableDatum: string[] = [];

            Object.keys(datum).slice(1).forEach(attribute => {
              searchableDatum.push(String(datum[attribute]));
            });

            return searchableDatum.join(' ').toLowerCase()
              .indexOf(search.toLowerCase()) >= 0;
          });
        }}
        {...props}
      />
    );
  };
};

export type HandleSearchType = ({ target }: any) => void;
export type HandleSearchTriggerType = (e: any) => void;
export type HandleSearchResetType = ({ keyCode }: any) => void;
export type FilterDataType = (data: any[]) => any[];
