import { Method } from 'axios';
import { useEffect, useState } from 'react';
import { request, Status } from '../requests';

export const useAxios = (
  method: Method,
  url: string,
  payload: {} | null = null,
  headers: {} | null = null
) => {
  const [response, setResponse] = useState<any>(null);
  const [status, setStatus] = useState<Status['name']>('idle');
  const [error, setError] = useState<any>(null);

  useEffect(() => {
    setStatus('loading');

    (async () => {
      try {
        const { data } = await request(method, url, payload, headers);

        setStatus('success');
        setResponse(data);
      } catch(err: any) {
        setStatus('failed');
        setError(err.response.data);
      }
    })();
  }, [method, url, payload, headers]);

  return { response, status, error };
};
